@@ -251,9 +251,7 @@ class cgyrodata_plot(data.cgyrodata):
 
       print('INFO: (data_plot.py) l_corr = {:.3f}'.format(l_corr[0]))
 
-   def plot_phi(self,w=0.5,wmax=0.0,field=0,theta=0.0,ymin='auto',ymax='auto',rms=0,fig=None):
-
-      print(rms)
+   def plot_phi(self,w=0.5,wmax=0.0,field=0,theta=0.0,ymin='auto',ymax='auto',norms=0,fig=None):
       
       if fig is None:
          fig = plt.figure(MYDIR,figsize=(self.lx,self.ly))
@@ -283,19 +281,12 @@ class cgyrodata_plot(data.cgyrodata):
       yn = np.sum(abs(f[:,1:,:]),axis=(0,1))/self.rho 
       sn = np.sum(abs(f[:,1:,:])**2,axis=(0,1))/self.rho**2
          
-      # Averages
-      y0_ave = average(y0,self.t,w,wmax)
-      yn_ave = average(yn,self.t,w,wmax)
-      print('INFO: (plot_phi) <|phi_0|>/rho_*D = {:.4f}'.format(y0_ave))
-      print('INFO: (plot_phi) <|phi_n|>/rho_*D = {:.4f}'.format(yn_ave))
-      
-      s0_ave = average(s0,self.t,w,wmax)
-      sn_ave = average(sn,self.t,w,wmax)
-      print('INFO: (plot_phi) sqrt[ <|phi_0|^2> ]/rho_*D = {:.4f}'.format(np.sqrt(s0_ave)))
-      print('INFO: (plot_phi) sqrt[ <|phi_n|^2> ]/rho_*D = {:.4f}'.format(np.sqrt(sn_ave)))
-
       s = np.ones(imax-imin+1)
-      if rms == 1:
+      if norms == 0:
+         s0_ave = average(s0,self.t,w,wmax)
+         sn_ave = average(sn,self.t,w,wmax)
+         print('INFO: (plot_phi) sqrt[ <|phi_0|^2> ]/rho_*D = {:.4f}'.format(np.sqrt(s0_ave)))
+         print('INFO: (plot_phi) sqrt[ <|phi_n|^2> ]/rho_*D = {:.4f}'.format(np.sqrt(sn_ave)))
          lab0=r'$\sqrt{\left\langle\left|'+ft+r'_0\right|^2\right\rangle}/\rho_{*D}$'
          labn=r'$\sqrt{\left\langle\left|'+ft+r'_n\right|^2\right\rangle}/\rho_{*D}$'
          ax.plot(self.t,np.sqrt(s0),label=lab0,linewidth=2)
@@ -303,6 +294,10 @@ class cgyrodata_plot(data.cgyrodata):
          ax.plot(self.t[imin:imax+1],np.sqrt(s0_ave)*s,'--k')
          ax.plot(self.t[imin:imax+1],np.sqrt(sn_ave)*s,'--k')
       else:
+         y0_ave = average(y0,self.t,w,wmax)
+         yn_ave = average(yn,self.t,w,wmax)
+         print('INFO: (plot_phi) <|phi_0|>/rho_*D = {:.4f}'.format(y0_ave))
+         print('INFO: (plot_phi) <|phi_n|>/rho_*D = {:.4f}'.format(yn_ave))
          lab0=r'$\left\langle \left|'+ft+r'_0\right|\right\rangle/\rho_{*D}$'
          labn=r'$\left\langle \left|'+ft+r'_n\right|\right\rangle/\rho_{*D}$'
          ax.plot(self.t,y0,label=lab0,linewidth=2)
@@ -688,9 +683,9 @@ class cgyrodata_plot(data.cgyrodata):
       return 'ang  Re(f)  Im(f)',x,y1,y2
          
    def plot_flux(self,w=0.5,wmax=0.0,field=0,moment='e',ymin='auto',ymax='auto',
-                 fc=0,fig=None,loc=2,nscale=0,cflux='auto',norm='elec'):
-         
-      if fig is None:
+                 fc=0,fig=None,ftype='screen',loc=2,nscale=0,cflux='auto',norm='elec'):
+      
+      if fig is None and ftype != 'nox':
          fig = plt.figure(MYDIR,figsize=(self.lx,self.ly))
 
       usec = self.getflux(cflux)
@@ -750,17 +745,18 @@ class cgyrodata_plot(data.cgyrodata):
       # Get index for average window
       imin,imax=iwindow(t,w,wmax)
 
-      # Otherwise plot
-      ax = fig.add_subplot(111)
-      ax.grid(which="both",ls=":")
-      ax.grid(which="major",ls=":")
-      ax.set_xlabel(self.tstr)
-
       color = ['k','m','b','c','g','r']
-
       windowtxt = '['+str(t[imin])+' < (c_s/a) t < '+str(t[imax])+']'
 
-      ax.set_title(r'$\mathrm{'+ntag+'} \quad '+windowtxt+'\quad ['+field_tag+']$')
+      print('INFO: (text.py) Average Window:'+windowtxt)
+
+      # Otherwise plot
+      if not ftype == 'nox':
+         ax = fig.add_subplot(111)
+         ax.grid(which="both",ls=":")
+         ax.grid(which="major",ls=":")
+         ax.set_xlabel(self.tstr)
+         ax.set_title(r'$\mathrm{'+ntag+'} \quad '+windowtxt+'\quad ['+field_tag+']$')
 
       for ispec in range(ns):
          y_norm = y[ispec,:]*norm_vec[ispec]
@@ -768,21 +764,35 @@ class cgyrodata_plot(data.cgyrodata):
          y_ave   = ave*np.ones(len(t))
          u = specmap(self.mass[ispec],self.z[ispec])
          label = r'$'+mtag+mnorm+'_'+u+'/'+mtag+self.gbnorm+': '+str(round(ave,3))+'$'
-         # Average
-         ax.plot(t[imin:imax+1],y_ave[imin:imax+1],'--',color=color[ispec])
-         # Time trace
-         ax.plot(t,y_norm,label=label,color=color[ispec])
+         if not ftype == 'nox':
+            # Average
+            ax.plot(t[imin:imax+1],y_ave[imin:imax+1],'--',color=color[ispec])
+            # Time trace
+            ax.plot(t,y_norm,label=label,color=color[ispec])
 
-         print('Var('+mtag+'_'+u+'): '+str(round(var,3)))
+      if not ftype == 'nox':
+         ax.legend(loc=loc)
+         if ymax != 'auto':
+            ax.set_ylim(top=float(ymax))
+         if ymin != 'auto':
+            ax.set_ylim(bottom=float(ymin))
+         fig.tight_layout(pad=0.3)
 
-      ax.legend(loc=loc)
+      title = '        '
+      for ispec in range(ns):
+         title = title+'       '+specmap(self.mass[ispec],self.z[ispec])+'       '
+      print(title)
 
-      if ymax != 'auto':
-         ax.set_ylim(top=float(ymax))
-      if ymin != 'auto':
-         ax.set_ylim(bottom=float(ymin))
-
-      fig.tight_layout(pad=0.3)
+      tag = [
+         'GAMMA [GB]',
+         'Q     [GB]',
+         'PI    [GB]']
+      for i in range(3):
+         bstr=''
+         for ispec in range(ns):
+            ave,var = variance(ys[ispec,i,:],t,w,wmax)
+            bstr = bstr+"{:7.3f}".format(ave)+' '+"({:4.1f})".format(var/ave)+' '
+         print(tag[i]+' '+bstr)
 
    def plot_xflux(self,w=0.5,wmax=0.0,moment='e',ymin='auto',ymax='auto',fig=None,nscale=0):
 
@@ -902,7 +912,7 @@ class cgyrodata_plot(data.cgyrodata):
       fig.tight_layout(pad=0.3)
 
    def plot_ky_flux(self,w=0.5,wmax=0.0,field=0,moment='e',ymin='auto',ymax='auto',
-                    fc=0,diss=0,fig=None,cflux='auto'):
+                    fc=0,ftype='screen',diss=0,fig=None,cflux='auto'):
 
       if self.n_n == 1:
          raise ValueError('(plot_ky_flux.py) Plot not available with a single mode.')
@@ -910,7 +920,7 @@ class cgyrodata_plot(data.cgyrodata):
       ns = self.n_species
       t  = self.t
 
-      if fig is None:
+      if fig is None and ftype != 'nox':
          fig = plt.figure(MYDIR,figsize=(self.ly*ns,self.ly))
 
       usec = self.getflux(cflux)
@@ -964,7 +974,6 @@ class cgyrodata_plot(data.cgyrodata):
          
       windowtxt = r'$['+str(t[imin])+' < (c_s/a) t < '+str(t[imax])+']'+cstr+'$'
 
-
       if ky[-1] < 0.0:
          ky = -ky
          xlabel=r'$-k_\theta \rho_s$'
@@ -979,18 +988,26 @@ class cgyrodata_plot(data.cgyrodata):
 
       # One plot per species
       for ispec in range(ns):
-         ax = fig.add_subplot(1,ns,ispec+1)
-         ax.set_xlabel(xlabel)
          u = specmap(self.mass[ispec],self.z[ispec])
-         ax.set_ylabel(r'$'+mtag+'_'+u+'$',color='k')
-         ax.set_title(windowtxt)
-         ax.bar(ky,ave[:,ispec],width=dk/1.1,color=color[ispec],
-                alpha=0.5,edgecolor='black',align='center')
+         if not ftype == 'nox':
+            ax = fig.add_subplot(1,ns,ispec+1)
+            ax.set_xlabel(xlabel)
+            ax.set_ylabel(r'$'+mtag+'_'+u+'$',color='k')
+            ax.set_title(windowtxt)
+            ax.bar(ky,ave[:,ispec],width=dk/1.1,color=color[ispec],
+                   alpha=0.5,edgecolor='black',align='center')
          
-         # Dissipation curve             
-         if diss == 1:
-            ax.plot(ky,self.alphadiss*ax.get_ylim()[1]*0.5,linewidth=2,color='k',alpha=0.2)
+            # Dissipation curve             
+            if diss == 1:
+               ax.plot(ky,self.alphadiss*ax.get_ylim()[1]*0.5,linewidth=2,color='k',alpha=0.2)
 
+            # Set axis ranges
+            ax.set_xlim([0,ky[-1]+dk])
+            if ymax != 'auto':
+               ax.set_ylim(top=float(ymax))
+            if ymin != 'auto':
+               ax.set_ylim(bottom=float(ymin))
+               
          # Maximum
          j = np.argmax(ave[:,ispec])
          if j < len(ky)-1:
@@ -998,15 +1015,9 @@ class cgyrodata_plot(data.cgyrodata):
          else:
             xs = ky[-1]
          print('INFO: (data_plot.py) Max(flux) occurs at ky*rho = {:.3f}'.format(xs))
-         
-         # Set axis ranges
-         ax.set_xlim([0,ky[-1]+dk])
-         if ymax != 'auto':
-            ax.set_ylim(top=float(ymax))
-         if ymin != 'auto':
-            ax.set_ylim(bottom=float(ymin))
 
-      fig.tight_layout(pad=0.3)
+      if not ftype == 'nox':
+         fig.tight_layout(pad=0.3)
 
    def plot_kxky_phi(self,field=0,theta=0.0,w=0.5,wmax=0.0,fig=None):
 
@@ -1103,7 +1114,7 @@ class cgyrodata_plot(data.cgyrodata):
          for n in nvec:
             num = r'$n='+str(n)+'$'
             ave[:] = average_n(abs(f[:,n,:]),self.t,w,wmax,nx)
-            ax.plot(kx+dk/2,ave[:],ls='steps',label=num)
+            ax.step(kx+dk/2,ave[:],label=num)
             if self.n_n > 16:
                ax.legend(loc=4, ncol=5, prop={'size':12})
             else:
