@@ -120,10 +120,10 @@ elif plot_type == 'phi':
    theta = float(sys.argv[5])
    ymin  = sys.argv[6]
    ymax  = sys.argv[7]
-   rms   = int(sys.argv[8])
+   norms = int(sys.argv[8])
    ftype = sys.argv[9]
 
-   head,x,y1,y2 = data_in.plot_phi(w=w,wmax=wmax,field=field,theta=theta,ymin=ymin,ymax=ymax,rms=rms)
+   head,x,y1,y2 = data_in.plot_phi(w=w,wmax=wmax,field=field,theta=theta,ymin=ymin,ymax=ymax,norms=norms)
 
    outfile = 'out.cgyro.phi.'+ftype
 
@@ -185,12 +185,14 @@ elif plot_type == 'flux':
    cflux  = sys.argv[12]
    norm   = sys.argv[13]
 
+   if ftype == 'nox' or ftype == 'dump':
+       doplot = False
+  
    if ftype == 'dump':
       cgyrodata_dump('./').dump_flux(fc=fc)
-      doplot=False
    else:
       data_in.plot_flux(w=w,wmax=wmax,field=field,moment=moment,
-                        ymin=ymin,ymax=ymax,fc=fc,loc=loc,nscale=nscale,cflux=cflux,norm=norm)
+                        ymin=ymin,ymax=ymax,fc=fc,ftype=ftype,loc=loc,nscale=nscale,cflux=cflux,norm=norm)
 
    outfile = 'out.cgyro.flux.'+ftype
 
@@ -207,12 +209,14 @@ elif plot_type == 'ky_flux':
    diss   = int(sys.argv[10])
    cflux  = sys.argv[11]
 
+   if ftype == 'nox' or ftype == 'dump':
+       doplot = False
+
    if ftype == 'dump':
       cgyrodata_dump('./').dump_ky_flux(w=w,wmax=wmax,field=field,moment=moment,fc=fc)
-      doplot=False
    else:
       data_in.plot_ky_flux(w=w,field=field,moment=moment,
-                           ymin=ymin,ymax=ymax,fc=fc,diss=diss,cflux=cflux)
+                           ymin=ymin,ymax=ymax,fc=fc,ftype=ftype,diss=diss,cflux=cflux)
 
    outfile = 'out.cgyro.ky_flux.'+ftype
 
