@@ -8,6 +8,8 @@ from .prgen_geqdsk import *
 from .prgen_contour import *
 from .prgen_shape import *
 
+plotpng = False
+
 if len(sys.argv) > 1:
    gfile   = sys.argv[1]
    nrz     = int(sys.argv[2])
@@ -37,7 +39,7 @@ si = np.zeros([nf+1,npsi])
 xi = np.zeros([4,npsi])
 for i in range(npsi-1):
    r=ri[:,i+1] ; z=zi[:,i+1]
-   if (np.mod(i,4) == 0) and (nfourier > 0):
+   if np.mod(i,4) == 0 and nfourier > 0 and plotpng:
       xplot = pnorm[i+1]
    else:
       xplot = 0.0
@@ -62,13 +64,13 @@ ci[1,:] = zero(rnorm,ci[1,:]) # c1
 ci[2,:] = zero(pnorm,ci[2,:]) # c2
 ci[3,:] = zero(pnorm,ci[3,:]) # c3
 
-f=open('out.dim','w')
-f.write(str(npsi)+'\n')
-f.write(str(nf+1)+'\n')
-f.write(str(efit['RCENTR'])+'\n')
-f.write(str(efit['BCENTR'])+'\n')
-f.write(str(efit['CURRENT']*1e-6)+'\n')
-f.close()
+with open('out.dim','w') as f:
+   f.write(str(npsi)+'\n')
+   f.write(str(nf+1)+'\n')
+   f.write(str(efit['RCENTR'])+'\n')
+   f.write(str(efit['BCENTR'])+'\n')
+   f.write(str(efit['CURRENT']*1e-6)+'\n')
+
 u = psi
 u = np.append(u,q)
 u = np.append(u,p)
@@ -83,5 +85,6 @@ u.tofile('out.data')
 if nfourier > 0:
    # Generate pure Fourier expansion coefficients, write to fluxfit.geo
    oldfourier(ri,zi,nfourier,rnorm)
-   # Plot radial profiles of cos,sin,etc
-   plot_coef(pnorm,ci,si,xi)
+   if plotpng:
+      # Plot radial profiles of cos,sin,etc
+      plot_coef(pnorm,ci,si,xi)
